pub struct InvocationResult {
pub exit_reason: u32,
pub exit_arg: u32,
pub return_value: u64,
pub gas_remaining: u64,
}Expand description
Invocation result. Both backends produce this shape on completion; rkyv-archived on the wire from the cached path’s response.
Fields
exit_reason: u32exit_arg: u32return_value: u64gas_remaining: u64Trait Implementations
Sourceimpl Archive for InvocationResult
impl Archive for InvocationResult
Sourceconst COPY_OPTIMIZATION: CopyOptimization<InvocationResult>
const COPY_OPTIMIZATION: CopyOptimization<InvocationResult>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedInvocationResult
type Archived = ArchivedInvocationResult
The archived representation of this type. Read more
Sourcetype Resolver = InvocationResultResolver
type Resolver = InvocationResultResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourcefn resolve(
&self,
resolver: <InvocationResult as Archive>::Resolver,
out: Place<<InvocationResult as Archive>::Archived>,
)
fn resolve( &self, resolver: <InvocationResult as Archive>::Resolver, out: Place<<InvocationResult as Archive>::Archived>, )
Creates the archived version of this value at the given position and
writes it to the given output. Read more
Sourceimpl Clone for InvocationResult
impl Clone for InvocationResult
Sourcefn clone(&self) -> InvocationResult
fn clone(&self) -> InvocationResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InvocationResult
impl Debug for InvocationResult
Sourceimpl PartialEq for InvocationResult
impl PartialEq for InvocationResult
Sourceimpl<__S> Serialize<__S> for InvocationResult
impl<__S> Serialize<__S> for InvocationResult
impl Copy for InvocationResult
impl Eq for InvocationResult
impl StructuralPartialEq for InvocationResult